@@ -12,6 +12,15 @@ phones <- str_join(
   num[, 4], num[, 5], num[, 6], " ", 
   num[, 7], num[, 8], num[, 9], num[, 10])
 
+test_that("special case are correct", {
+  # These tests really should compare to character matrices, but str_match
+  # returns matrices with dimnames set it's real pain
+  expect_that(c(str_match(NA, "(a)")), 
+    equals(c(NA_character_, NA_character_)))
+  expect_that(c(str_match(character(), "(a)")), 
+    equals(character()))
+})
+
 test_that("single match works when all match", {
   matches <- str_match(phones, "\\(([0-9]{3})\\) ([0-9]{3}) ([0-9]{4})")
   
