@@ -30,6 +30,18 @@ test_that("specifying only start subsets to end", {
   expect_that(str_sub(alphabet, 24), equals(c("xyz")))  
 })
 
+test_that("specifying Inf as end selects entire string", {
+  expect_that(
+    str_sub("ABCDEF", c(4, 5), c(5, Inf)),
+    equals(c("DE", "EF"))
+  ) 
+  
+  expect_that(
+    str_sub("ABCDEF", c(4, 5), c(Inf, Inf)),
+    equals(c("DEF", "EF"))
+  )
+})
+
 test_that("missing arguments give missing results", {
   expect_that(str_sub(NA), equals(NA_character_))
   expect_that(str_sub(NA, 1, 3), equals(NA_character_))
